import { PluginObject } from "vue";
import VueCompositionApi from "@vue/composition-api";
import { extend, ValidationObserver, ValidationProvider } from "vee-validate";
import {email, integer, max, max_value, min, min_value, required} from "vee-validate/dist/rules";
import DynamicForm from "@/plugin-components/DynamicForm.vue";
import { UploaderPlugin } from "@syncfusion/ej2-vue-inputs";


export const DynamicFormsPlugin: PluginObject<any> = {
  install(Vue, options) {
    Vue.use(VueCompositionApi);
    extend('required', {
      ...required,
      message: '{_field_} is required'
    });

    extend('email', {
      ...email,
      message: 'You must input a valid email address.'
    });
    extend('max', {
      ...max,
      message: 'The {_field_} field must have fewer than {length} characters.'
    });
    extend('max_value', {
      ...max_value,
      message: '{_field_} must be less than {max}'
    });
    extend('min', {
      ...min,
      message: 'The {_field_} field must have more than {length} characters.'
    });
    extend('min_value', {
      ...min_value,
      message: '{_field_} must be greater than {min}'
    });
    extend('integer', {
      ...integer,
      message: '{_field_} must be an integer.'
    });
    extend('must_match', {
      params: ['target'],
      validate(value, { target }: any) {
        return value === target;
      },
      message: "{_field_} must match {target}."
    });
    extend('must_be_true', {
      validate(value) {
        return value;
      },
      message: "{_field_} must be checked."
    })
    Vue.component("ValidationProvider", ValidationProvider);
    Vue.component("ValidationObserver", ValidationObserver);
    Vue.component("DynamicForm", DynamicForm);
    Vue.use(UploaderPlugin);
  }
};
